module.exports = (api, { componentName }) => {

  api.extendPackage({
    name: componentName,
    main: `dist/${componentName}.umd.js`,
    module: `dist/${componentName}.common.js`,
    files: [
      "dist/*.css",
      "dist/*.map",
      "dist/*.js",
    ],
    scripts: {
      serve: "vue-cli-service serve ./example/main.js --open",
      build: `vue-cli-service build --target lib --name ${componentName}`,
    },
    private: false,
    keywords: [
      "vue",
      "component"
    ]
  })

  api.render('./template')

  api.postProcessFiles(files => {
    const rootFile = 'src/index.js'
    const immutableFiles = ['src/components/HelloWorld.vue', rootFile]

    updateFiles(files, /^src\//, 'example/', (file) => immutableFiles.indexOf(file) !== -1)

    rename(files, rootFile, 'src/main.js')

    updateFiles(files,  /\/HelloWorld\./, `/${componentName}.`)
  })

  function updateFiles(files, regex, replace, addicionalFilter) {
    const filter = addicionalFilter || ((file) => false)

    for (const file in files) {
      if (!regex.test(file) || filter(file)) {
        continue;
      }
      const migratedFile = file.replace(regex, replace);
      rename(files, file, migratedFile)
    }
  }

  function rename(files, oldName, newName) {
    files[newName] = files[oldName];
    delete files[oldName];
  }
}
